<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Eventpress
 */

if ( ! function_exists( 'eventpress_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function eventpress_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		esc_html_x( 'Posted on %s', 'post date', 'eventpress' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);

	$byline = sprintf(
		esc_html_x( 'by %s', 'post author', 'eventpress' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);

	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; // WPCS: XSS OK.

}
endif;

if ( ! function_exists( 'eventpress_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function eventpress_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'eventpress' ) );
		if ( $categories_list && eventpress_categorized_blog() ) {
			printf( '<span class="cat-links">' . esc_html__( 'Posted in %1$s', 'eventpress' ) . '</span>', $categories_list ); // WPCS: XSS OK.
		}

		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( '', esc_html__( ', ', 'eventpress' ) );
		if ( $tags_list ) {
			printf( '<span class="tags-links">' . esc_html__( 'Tagged %1$s', 'eventpress' ) . '</span>', $tags_list ); // WPCS: XSS OK.
		}
	}

	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link">';
		/* translators: %s: post title */
		comments_popup_link( sprintf( wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'eventpress' ), array( 'span' => array( 'class' => array() ) ) ), get_the_title() ) );
		echo '</span>';
	}

	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'eventpress' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<span class="edit-link">',
		'</span>'
	);
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function eventpress_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'eventpress_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'eventpress_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so eventpress_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so eventpress_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in eventpress_categorized_blog.
 */
function eventpress_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'eventpress_categories' );
}
add_action( 'edit_category', 'eventpress_category_transient_flusher' );
add_action( 'save_post',     'eventpress_category_transient_flusher' );

/**
 * Function that returns if the menu is sticky
 */
if (!function_exists('eventpress_sticky_menu')):
    function eventpress_sticky_menu()
    {
        $is_sticky = get_theme_mod('sticky_header_setting');

        if ($is_sticky == '1'):
            return 'sticky-nav';
        else:
            return false;
        endif;
    }
endif;


/**
 * Register Google fonts for Eventpress.
 */
function eventpress_google_font() {
	
    $get_fonts_url = '';
		
    $font_families = array();
 
	$font_families = array('Dancing Script:400,700','Fira Sans:100,200,300,400,500,600,700,800','Cinzel Decorative:400,700,900');
	
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
        $get_fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );

    return $get_fonts_url;
}

function eventpress_scripts_styles() {
    wp_enqueue_style( 'eventpress-fonts', eventpress_google_font(), array(), null );
}
add_action( 'wp_enqueue_scripts', 'eventpress_scripts_styles' );

/**
 * Register Breadcrumb for Multiple Variation
 */
function eventpress_breadcrumbs_style() {
	get_template_part('./sections/eventpress','breadcrumb');	
}


/**
 * This Function Check whether Sidebar active or Not
 */
if(!function_exists( 'eventpress_post_layout' )) :
function eventpress_post_layout(){
	if(is_active_sidebar('sidebar-primary'))
		{ echo 'col-lg-8 col-md-12'; } 
	else 
		{ echo 'col-lg-12 col-md-12'; }  
} endif; 


// title seprator 
function eventpress_title_seprator() {
	$hide_show_seprator = get_theme_mod('hide_show_seprator','1');
	$seprator_icon = get_theme_mod('seprator_icon','fa-bell');
	?>
					
	<?php if($hide_show_seprator == '1') : ?>	
			<div class="st-separator">
			   <span></span><span class="sepBg"><i class="fa <?php echo esc_attr($seprator_icon); ?>"></i></span><span></span>
		   </div>
	<?php endif; 
} 

// title seprator dark
function eventpress_title_seprator_dark() {
	$hide_show_seprator = get_theme_mod('hide_show_seprator','1');
	$seprator_icon = get_theme_mod('seprator_icon','fa-bell');
	?>
	<?php if($hide_show_seprator == '1') : ?>	
			<div class="st-separator w-line">
			   <span></span><span class="sepBg"><i class="fa <?php echo esc_attr($seprator_icon); ?>"></i></span><span></span>
		   </div>
	<?php endif; 
} 

if( ! function_exists( 'eventpress_customizer_options' ) ):
    function eventpress_customizer_options() {
			$logo_width 					 = get_theme_mod('logo_width','140');
			 $output_css = '';
			if($logo_width !== '') { 
			$output_css .=".logo-bbc img {
					width: 100%;
					max-width: " .esc_attr($logo_width). "px;
				}\n";
			}
	 wp_add_inline_style( 'eventpress-style', $output_css );
    }
endif;
add_action( 'wp_enqueue_scripts', 'eventpress_customizer_options' );		
?>
